# Copyright 2015 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Main entry point
"""
from pyramid.config import Configurator
from pyramid.authentication import BasicAuthAuthenticationPolicy
from pyramid.authorization import ACLAuthorizationPolicy

from rutabaga.config import RutabagaConfig


def authenticate(username, password, request):
    rutabaga_config = RutabagaConfig()
    admin_username = '{prefix}{username}'.format(
        prefix=rutabaga_config.get('admin_api_username_prefix'),
        username=rutabaga_config.get('admin_api_username'))
    api_secret = rutabaga_config.get('admin_api_secret')
    if username == admin_username and password == api_secret:
        return ['admin']
    else:
        return None


authn_policy = BasicAuthAuthenticationPolicy(authenticate, debug=True)
# Pyramid insists that an AuthorizationPolicy is set, although we
# do not make use of it.
authr_policy = ACLAuthorizationPolicy()


def main(global_config, **settings):
    config = Configurator(settings=settings)
    config.include("cornice")
    config.set_authentication_policy(authn_policy)
    config.set_authorization_policy(authr_policy)
    config.scan("rutabaga.views")
    return config.make_wsgi_app()
