#!/usr/bin/env python3

import os
from random import randint
import unittest

import requests
from testtools import TestCase
import yaml

SNAP_PROXY = 'snapproxy.launchpad.dev'
SNAP_PROXY_PORT = 3128

SNAP_PROXY_API = 'builderproxyapi.launchpad.dev'
SNAP_PROXY_API_PORT = 8080

TEST_URL = 'http://www.canonical.com'

stream = open(os.path.join(
    os.path.dirname(__file__), '..', 'config.yaml'), 'r')
CONFIG = yaml.safe_load(stream)


class TestProxyApiIntegration(TestCase):

    def createToken(self, username):
        token_endpoint = 'http://{url}:{port}/tokens'.format(
            url=SNAP_PROXY_API, port=SNAP_PROXY_API_PORT)
        payload = {'username': username}
        r = requests.post(token_endpoint, json=payload,
                          auth=(self.admin_username, self.admin_secret))
        assert r.status_code == 200
        return r.json()

    def setUp(self):
        super(TestProxyApiIntegration, self).setUp()
        self.admin_username = '{}{}'.format(
            CONFIG['admin_api_username_prefix'], CONFIG['admin_api_username'])
        self.admin_secret = CONFIG['admin_api_secret']
        self.token = self.createToken('BUILD-{}'.format(randint(100, 999)))
        self.username = self.token['username']
        self.secret = self.token['secret']
        self.proxies = {
            'http': 'http://{username}:{password}@{url}:{port}'.format(
                username=self.username,
                password=self.secret,
                url=SNAP_PROXY,
                port=SNAP_PROXY_PORT)
            }

    def test_proxy_basic_auth(self):
        r = requests.get(TEST_URL, proxies=self.proxies)
        self.assertEqual(200, r.status_code)


if __name__ == '__main__':
    unittest.main(warnings='ignore')
